
From: Tobias Klauser <tklauser@nuerscht.ch>

The amd8111e driver directly assigns the DMA mask to the dma_mask member of
the struct pci_dev instead of using pci_set_dma_mask().  This makes the
call to pci_dma_supported() redundant as pci_set_dma_mask() does this
check.

I do not own this device so I only compile-tested this patch.

Signed-off-by: Tobias Klauser <tklauser@nuerscht.ch>
Cc: Jeff Garzik <jgarzik@pobox.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 drivers/net/amd8111e.c |    8 ++++----
 1 files changed, 4 insertions(+), 4 deletions(-)

diff -puN drivers/net/amd8111e.c~use-pci_set_dma_mask-instead-of-direct-assignment-of-dma-mask drivers/net/amd8111e.c
--- 25/drivers/net/amd8111e.c~use-pci_set_dma_mask-instead-of-direct-assignment-of-dma-mask	Mon Jun 20 15:30:30 2005
+++ 25-akpm/drivers/net/amd8111e.c	Mon Jun 20 15:30:30 2005
@@ -87,6 +87,7 @@ Revision History:
 #include <linux/if_vlan.h>
 #include <linux/ctype.h>	
 #include <linux/crc32.h>
+#include <linux/dma-mapping.h>
 
 #include <asm/system.h>
 #include <asm/io.h>
@@ -2006,12 +2007,11 @@ static int __devinit amd8111e_probe_one(
 	}
 
 	/* Initialize DMA */
-	if(!pci_dma_supported(pdev, 0xffffffff)){
+	if (pci_set_dma_mask(pdev, DMA_32BIT_MASK) < 0) {
 		printk(KERN_ERR "amd8111e: DMA not supported,"
 			"exiting.\n");
-		goto  err_free_reg;
-	} else
-		pdev->dma_mask = 0xffffffff;
+		goto err_free_reg;
+	}
 	
 	reg_addr = pci_resource_start(pdev, 0);
 	reg_len = pci_resource_len(pdev, 0);
_
